==> qt3d-opensource-src_5.12.8+dfsg.orig.tar.xz: qt3d-everywhere-src-5.12.8/src/render/jobs/job_common_p.h <==
/****************************************************************************
**
** Copyright (C) 2015 Paul Lemire
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt3D module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QT3DRENDER_RENDER_JOB_COMMON_P_H
#define QT3DRENDER_RENDER_JOB_COMMON_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include <Qt3DCore/private/qaspectjob_p.h>

QT_BEGIN_NAMESPACE

namespace Qt3DRender {

namespace Render {

namespace JobTypes {

    enum JobType {
        LoadBuffer = 1,
        FrameCleanup,
        UpdateShaderDataTransform,
        CalcBoundingVolume,
        CalcTriangleVolume,
        LoadGeometry,
        LoadScene,
        LoadTextureData,
        PickBoundingVolume,
        RayCasting,
        RenderView,
        UpdateTransform,
        UpdateTreeEnabled,
        ExpandBoundingVolume,
        FrameSubmissionPart1,
        LayerFiltering,
        EntityComponentTypeFiltering,
        MaterialParameterGathering,
        RenderViewBuilder,
        GenericLambda,
        FrustumCulling,
        LightGathering,
        UpdateWorldBoundingVolume,
        FrameSubmissionPart2,
        DirtyBufferGathering,
        DirtyVaoGathering,
        DirtyTextureGathering,
        DirtyShaderGathering,
        SendRenderCapture,
        SendBufferCapture,
        SyncRenderViewCommandBuilding,
        SyncRenderViewInitialization,
        SyncRenderViewCommandBuilder,
        SyncFrustumCulling,
        ClearBufferDrawIndex,
        UpdateMeshTriangleList,
        FilterCompatibleTechniques,
        UpdateLevelOfDetail,
        SyncTextureLoading,
        LoadSkeleton,
        UpdateSkinningPalette,
        ProximityFiltering,
        SyncFilterEntityByLayer,
        SyncMaterialGatherer,
        UpdateLayerEntity,
        UpdateEntityHierarchy,
        SendTextureChangesToFrontend
    };

} // JobTypes

} // Render

} // Qt3DRender

QT_END_NAMESPACE

#endif // QT3DRENDER_RENDER_JOB_COMMON_P_H

==> qt3d-opensource-src_5.15.18+dfsg.orig.tar.xz: qt3d-everywhere-src-5.15.18/src/render/jobs/job_common_p.h <==
/****************************************************************************
**
** Copyright (C) 2015 Paul Lemire
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt3D module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QT3DRENDER_RENDER_JOB_COMMON_P_H
#define QT3DRENDER_RENDER_JOB_COMMON_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include <Qt3DCore/private/qaspectjob_p.h>

QT_BEGIN_NAMESPACE

namespace Qt3DRender {

namespace Render {

namespace JobTypes {

    enum JobType {
        LoadBuffer = 1,
        FrameCleanup,
        UpdateShaderDataTransform,
        CalcBoundingVolume,
        CalcTriangleVolume,
        LoadGeometry,
        LoadScene,
        LoadTextureData,
        PickBoundingVolume,
        RayCasting,
        RenderView,
        UpdateTransform,
        UpdateTreeEnabled,
        ExpandBoundingVolume,
        FrameSubmissionPart1,
        LayerFiltering,
        EntityComponentTypeFiltering,
        MaterialParameterGathering,
        RenderCommandUpdater,
        GenericLambda,
        FrustumCulling,
        LightGathering,
        UpdateWorldBoundingVolume,
        FrameSubmissionPart2,
        DirtyBufferGathering,
        DirtyVaoGathering,
        DirtyTextureGathering,
        DirtyShaderGathering,
        SendRenderCapture,
        SendBufferCapture,
        SyncRenderViewPreCommandUpdate,
        SyncRenderViewInitialization,
        SyncRenderViewPostCommandUpdate,
        SyncFrustumCulling,
        ClearBufferDrawIndex,
        UpdateMeshTriangleList,
        FilterCompatibleTechniques,
        UpdateLevelOfDetail,
        SyncLoadingJobs,
        LoadSkeleton,
        UpdateSkinningPalette,
        ProximityFiltering,
        SyncFilterEntityByLayer,
        SyncMaterialGatherer,
        UpdateLayerEntity,
        SendTextureChangesToFrontend,
        SendSetFenceHandlesToFrontend,
        SendDisablesToFrontend,
        RenderViewCommandBuilder,
        SyncRenderViewPreCommandBuilding
    };

} // JobTypes

} // Render

} // Qt3DRender

QT_END_NAMESPACE

#endif // QT3DRENDER_RENDER_JOB_COMMON_P_H
